/////////////////////////////////////////////////////////////////////////////// 
// Copyright (C) 2002-2024, Open Design Alliance (the "Alliance"). 
// All rights reserved. 
// 
// This software and its documentation and related materials are owned by 
// the Alliance. The software may only be incorporated into application 
// programs owned by members of the Alliance, subject to a signed 
// Membership Agreement and Supplemental Software License Agreement with the
// Alliance. The structure and organization of this software are the valuable  
// trade secrets of the Alliance and its suppliers. The software is also 
// protected by copyright law and international treaty provisions. Application  
// programs incorporating this software must include the following statement 
// with their copyright notices:
//   
//   This application incorporates Open Design Alliance software pursuant to a license 
//   agreement with Open Design Alliance.
//   Open Design Alliance Copyright (C) 2002-2024 by Open Design Alliance. 
//   All rights reserved.
//
// By use of this software, its documentation or related materials, you 
// acknowledge and accept the above terms.
///////////////////////////////////////////////////////////////////////////////
package com.opendesign.teigha.samples.java;

import com.opendesign.core.Globals;
import com.opendesign.core.OdEdCommandStack;
import com.opendesign.td.ExDbCommandContext;
import com.opendesign.td.ExStringIO;
import com.opendesign.td.OdDbCommandContext;
import com.opendesign.td.OdDbDatabase;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.File;

public class DwgToPngFileConverter extends BaseFileConverter {

    Logger logger = LoggerFactory.getLogger(DwgToBmpFileConverter.class);

    public void convertFile(File from, File to) throws FileConvertException {

        OdDbDatabase db = OdaSystem.hostApp.readFile(from.getAbsolutePath());

        //////// PNG start second variant ///////
        OdEdCommandStack pCommands = Globals.odedRegCmds();
        String cmd = "bmpout";
        String args =
                "Extents\n" + // What to export
                        "24\n" + // BitPerPixel
                        "768\n" + // width
                        "1024\n" + // height
                        "ON\n" + // Plot generation
                        to.getAbsolutePath() + "\n";

        logger.info("{}} `{}`", cmd, args);

        ExStringIO strIO = ExStringIO.create(args);
        OdDbCommandContext pCon = ExDbCommandContext.createObject(strIO, db);
        pCommands.executeCommand(cmd, pCon);
        //////// PNG finish second variant ///////

    }

    @Override
    public String getContentType() {
        return "image/png";
    }

    @Override
    public String getFileExtension() {
        return "png";
    }
}
