/////////////////////////////////////////////////////////////////////////////// 
// Copyright (C) 2002-2024, Open Design Alliance (the "Alliance"). 
// All rights reserved. 
// 
// This software and its documentation and related materials are owned by 
// the Alliance. The software may only be incorporated into application 
// programs owned by members of the Alliance, subject to a signed 
// Membership Agreement and Supplemental Software License Agreement with the
// Alliance. The structure and organization of this software are the valuable  
// trade secrets of the Alliance and its suppliers. The software is also 
// protected by copyright law and international treaty provisions. Application  
// programs incorporating this software must include the following statement 
// with their copyright notices:
//   
//   This application incorporates Open Design Alliance software pursuant to a license 
//   agreement with Open Design Alliance.
//   Open Design Alliance Copyright (C) 2002-2024 by Open Design Alliance. 
//   All rights reserved.
//
// By use of this software, its documentation or related materials, you 
// acknowledge and accept the above terms.
///////////////////////////////////////////////////////////////////////////////
package com.opendesign.teigha.samples.tests;

import com.opendesign.core.MemoryManager;
import com.opendesign.core.MemoryTransaction;
import com.opendesign.td.ExHostAppServices;
import com.opendesign.td.ExStringIO;
import com.opendesign.td.TD_Db;
import com.opendesign.teigha.samples.java.BaseFileConverter;
import com.opendesign.teigha.samples.java.Converters;
import com.opendesign.teigha.samples.java.FileConvertException;
import com.opendesign.teigha.samples.java.FileConverter;
import org.apache.commons.io.FileUtils;
import org.junit.Assert;
import org.junit.jupiter.api.AfterAll;
import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.Test;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.File;

public class ODALoadJNILibrariesTest {

    private static Logger logger = LoggerFactory.getLogger(ODALoadJNILibrariesTest.class);

    private ThreadLocal<MemoryTransaction> memTr = new ThreadLocal<MemoryTransaction>();

    @BeforeAll
    private static void beforeAll() {
        ODAInitTest.init();
        logger.info("odInitialize");
        TD_Db.odInitialize(new BaseFileConverter.CustomSystemServices());
    }

    @AfterAll
    private static void afterAll() {
        logger.info("odUninitialize");
        TD_Db.odUninitialize();
    }

    //    @BeforeEach
    private void startTransaction() {
        logger.info("startTransaction");
        memTr.set(MemoryManager.GetMemoryManager().StartTransaction());
    }

    //    @AfterEach
    private void stopTransaction() {
        logger.info("stopTransaction");
        MemoryManager.GetMemoryManager().StopTransaction(memTr.get());
    }

    @Test
    void test1() {
        logger.info(String.valueOf(com.opendesign.core.Globals.OdaPI));
    }

    @Test
    void test2() {
        ExHostAppServices hostApp = new ExHostAppServices();
        logger.info("product: {}, version: {}", hostApp.product(), hostApp.versionString());
    }

    @Test
    void testStringIO() {
        String txvLib = "WinBitmap.txv";
        String tmp = txvLib + "\nExtents\n\n" + "768\n1024\n\n255\n" + "empty.dwg";
        ExStringIO strIO = ExStringIO.create(tmp);
        logger.info("strIO created: {}", strIO);
    }

    @Test
    void testConverterDwgToPdf() throws FileConvertException {
        runConverter("pdf");
    }

    @Test
    void testConverterDwgToPng() throws FileConvertException {
        runConverter("png");
    }

//        @Test
    void testConverterDwgToBmp() throws FileConvertException {
        runConverter("bmp");
    }

    private void runConverter(String ext) throws FileConvertException {
        FileConverter converter = Converters.getInstance().get(ext);
        File inputFile = new File("empty.dwg");
        File outFile = new File("target/empty.dwg." + ext);
        logger.info("Converting file {} to {}", inputFile, outFile);

        startTransaction();
        converter.convertFile(inputFile, outFile);
        stopTransaction();

        Assert.assertTrue(String.format("File %s not found:", outFile), outFile.exists());
        logger.info("File size: {} {}", outFile, FileUtils.sizeOf(outFile));
        long len = outFile.length();
        Assert.assertTrue(len > 0);
    }


}
